﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DepPropDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private List<Presence> presences = new List<Presence>();

        public MainWindow()
        {
            InitializeComponent();
        }

        private void NewMenuItem_Click(object sender, RoutedEventArgs e)
        {
            presences.Clear();
            UpdateGUI();
        }

        private void UpdateGUI()
        {
            DataBox.Items.Clear();
            foreach(Presence presence in presences)
            {
                DataBox.Items.Add(presence);
            }
        }

        private void OpenMenuItem_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            if (dialog.ShowDialog() == true)
            {
                LoadData(dialog.FileName);
            }
        }

        private void LoadData(string fileName)
        {
            presences.Clear();
            using(StreamReader reader = new StreamReader(fileName))
            {
                string line;
                while ((line = reader.ReadLine()) != null)
                {
                    Presence presence = new Presence(line);
                    presences.Add(presence);
                }
            }
            UpdateGUI();
        }

        private void SaveMenuItem_Click(object sender, RoutedEventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            if (dialog.ShowDialog() == true)
            {
                SaveData(dialog.FileName);
            }

        }

        private void SaveData(string fileName)
        {
            using (StreamWriter writer = new StreamWriter(fileName))
            {
                foreach(Presence presence in presences)
                {
                    writer.WriteLine(presence.CSVFormat());
                }
            }
        }

        private void ExitMenuItem_Click(object sender, RoutedEventArgs e)
        {
            Application.Current.Shutdown();
        }

        private void AddPresenceMenuItem_Click(object sender, RoutedEventArgs e)
        {
            AddPresenceDialog dialog = new AddPresenceDialog();
            if (dialog.ShowDialog() == true)
            {
                presences.Add(dialog.Presence);
                UpdateGUI();
            }
        }
    }
}
